@@ -27,6 +27,7 @@
 #include <QKeyEvent>
 #include <QWhatsThis>
 #include <QScrollArea>
+#include <QStyle>
 #include <QVBoxLayout>
 #include <QPushButton>
 #include <QLoggingCategory>
@@ -52,14 +53,14 @@ public:
     Private() {}
     QMap<KPageWidgetItem*, KCModuleProxy*> mPages;
     QMap<KPageWidgetItem*, KCModuleInfo*> mModules;
-    KPageWidget* mPageWidget;
-    QVBoxLayout* mLayout;
-    QDialogButtonBox* mButtons;
-    KAuth::ObjectDecorator* mApplyAuthorize;
-    QPushButton* mApply;
-    QPushButton* mReset;
-    QPushButton* mDefault;
-    QPushButton* mHelp;
+    KPageWidget* mPageWidget = nullptr;
+    QVBoxLayout* mLayout = nullptr;
+    QDialogButtonBox* mButtons = nullptr;
+    KAuth::ObjectDecorator* mApplyAuthorize = nullptr;
+    QPushButton* mApply = nullptr;
+    QPushButton* mReset = nullptr;
+    QPushButton* mDefault = nullptr;
+    QPushButton* mHelp = nullptr;
     bool pageChangeSupressed;
 };
 
@@ -124,7 +125,7 @@ KCModuleInfo * ModuleView::activeModule() const
 const KAboutData * ModuleView::aboutData() const
 {
     KCModuleProxy * activeModule = d->mPages.value( d->mPageWidget->currentPage() );
-    KAboutData * aboutData = 0;
+    KAboutData * aboutData = nullptr;
     if( activeModule ) {
         aboutData = const_cast<KAboutData*>( activeModule->aboutData() );
     }
@@ -132,10 +133,10 @@ const KAboutData * ModuleView::aboutData() const
         aboutData->setProgramIconName( activeModule->moduleInfo().service()->icon() );
         return aboutData;
     }
-    return 0;
+    return nullptr;
 }
 
-void ModuleView::loadModule( QModelIndex menuItem )
+void ModuleView::loadModule( const QModelIndex &menuItem )
 {
     if ( !menuItem.isValid() ) {
         return;
@@ -149,9 +150,9 @@ void ModuleView::loadModule( QModelIndex menuItem )
         indexes << menuItem;
     }
 
-    foreach ( QModelIndex module, indexes ) {
-        MenuItem *menuItem = module.data( Qt::UserRole ).value<MenuItem*>();
-        addModule( &menuItem->item() );
+    foreach ( const QModelIndex &module, indexes ) {
+        MenuItem *newMenuItem = module.data( Qt::UserRole ).value<MenuItem*>();
+        addModule( &newMenuItem->item() );
     }
     // changing state is not needed here as the adding / changing of pages does it
 }
@@ -183,7 +184,7 @@ void ModuleView::addModule( KCModuleInfo *module )
     KPageWidgetItem *page = new KPageWidgetItem( moduleScroll, module->moduleName() );
     // Provide information to the users
 
-    if( module->service()->hasServiceType("SystemSettingsExternalApp") ||  // Is it an external app?
+    if( module->service()->hasServiceType(QStringLiteral("SystemSettingsExternalApp")) ||  // Is it an external app?
             module->service()->substituteUid() ) { // ...or does it require UID substituion?
         QWidget * externalWidget = new ExternalAppModule( this, module );
         moduleScroll->setWidget( externalWidget );
@@ -223,8 +224,8 @@ void ModuleView::updatePageIconHeader( KPageWidgetItem * page, bool light )
     }
 
     if( moduleProxy && moduleProxy->realModule()->useRootOnlyMessage() ) {
-        page->setHeader( moduleInfo->comment() + "<br><small>" + moduleProxy->realModule()->rootOnlyMessage() + "</small>" );
-        page->setIcon( KDE::icon( moduleInfo->icon(), QStringList() << "dialog-warning" ) );
+        page->setHeader( moduleInfo->comment() + QStringLiteral("<br><small>") + moduleProxy->realModule()->rootOnlyMessage() + QStringLiteral("</small>") );
+        page->setIcon( KDE::icon( moduleInfo->icon(), QStringList() << QStringLiteral("dialog-warning") ) );
     }
 }
 
@@ -325,8 +326,8 @@ void ModuleView::moduleHelp()
     if( docPath.isEmpty() ) {
         return;
     }
-    QUrl url( "help:/"+docPath );
-    QProcess::startDetached("khelpcenter", QStringList() << url.url());
+    QUrl url( QStringLiteral("help:/")+docPath );
+    QProcess::startDetached(QStringLiteral("khelpcenter"), QStringList() << url.url());
 }
 
 void ModuleView::activeModuleChanged(KPageWidgetItem * current, KPageWidgetItem * previous)
@@ -346,8 +347,23 @@ void ModuleView::activeModuleChanged(KPageWidgetItem * current, KPageWidgetItem
 
     KCModuleProxy * activeModule = d->mPages.value( d->mPageWidget->currentPage() );
     if (activeModule) {
-        KActivities::ResourceInstance::notifyAccessed(QUrl("kcm:" + activeModule->moduleInfo().service()->storageId()),
-                "org.kde.systemsettings");
+        KActivities::ResourceInstance::notifyAccessed(QUrl(QStringLiteral("kcm:") + activeModule->moduleInfo().service()->storageId()),
+                QStringLiteral("org.kde.systemsettings"));
+        if (activeModule->realModule() && activeModule->realModule()->inherits("KCModuleQml")) {
+            d->mButtons->setContentsMargins(
+                style()->pixelMetric(QStyle::PM_LayoutLeftMargin),
+                style()->pixelMetric(QStyle::PM_LayoutTopMargin),
+                style()->pixelMetric(QStyle::PM_LayoutRightMargin),
+                style()->pixelMetric(QStyle::PM_LayoutBottomMargin));
+            d->mLayout->setContentsMargins(0, 0, 0, 0);
+        } else {
+            d->mButtons->setContentsMargins(0, 0, 0, 0);
+            d->mLayout->setContentsMargins(
+                style()->pixelMetric(QStyle::PM_LayoutLeftMargin),
+                style()->pixelMetric(QStyle::PM_LayoutTopMargin),
+                style()->pixelMetric(QStyle::PM_LayoutRightMargin),
+                style()->pixelMetric(QStyle::PM_LayoutBottomMargin));
+        }
     }
 }
 
